=== modified file 'src/Error.h'
--- src/Error.h	2013-09-04 15:05:39 +0000
+++ src/Error.h	2013-09-05 22:40:17 +0000
@@ -1,9 +1,22 @@
-/**
- * An Error is a data structure that inherets from BaseObject.
- * 
- * An Error represents an error that can occur.
- */
-
+
+/*
+    (C) Gustav Hartvigsson, 2013.
+    
+    This program is free software: you can redistribute it and/or modify
+    it under the terms of the GNU Lesser General Public License as
+    published by the Free Software Foundation, either version 3 of the
+    License.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
+
+/** @file */
 
 #ifndef __H_ERROR__
 #define __H_ERROR__
@@ -14,11 +27,20 @@
 #include <stdio.h>
 #include <string.h>
 
+/**
+ * An opaque datastructure that holds the SError's private data.
+ */
 typedef struct _SErrorPrivate SErrorPrivate;
 
+
+/**
+ * An SError is a data structure that inherets from SBaseObjectInstance.
+ * 
+ * An SError represents an error that can occur.
+ */
 typedef struct _SError {
   SBaseObjectInstance parent;
-  SErrorPrivate * priv; //Pimple pointer to the private data.
+  SErrorPrivate * priv; /** Pimple pointer to the private data. */
   
 } SError;
 
@@ -30,24 +52,36 @@
   
 } SErrorClass;
 
+/** @brief
+ * The different error types.
+ */
 typedef enum {
-  S_ERROR_NONE = 0,
-  S_ERROR_INPUT_OUTPUT,
-  S_ERROR_OVERFLOW,
-  S_ERROR_OTHER = INT_MAX - 1,
-  S_ERROR_NULL = INT_MAX
+  S_ERROR_NONE = 0, /** Not on error */
+  S_ERROR_INPUT_OUTPUT, /** An I/O error */
+  S_ERROR_OVERFLOW, /** An Overflow error */
+  S_ERROR_OTHER = INT_MAX - 1, /** Some unknowned error */
+  S_ERROR_NULL = INT_MAX /** An NULL error */
 } SErrorType;
 
 
 /**
- * the constructor for the 
+ * the constructor for the an SError
  */
 SError * s_error_new (SErrorType error, char * message);
 
+/**
+ * This function calles the deinitize method of the object.
+ */
 void s_error_free (SError * self);
 
+/**
+ * This function returns the ErrorType of on object.
+ */
 SErrorType s_error_get_error_type (SError * self);
 
+/**
+ * This function prints the current error to stdout.
+ */
 void s_error_print_error (SError * self);
 
 #endif

=== modified file 'src/SimpleTypeSystem.h'
--- src/SimpleTypeSystem.h	2013-09-04 15:05:39 +0000
+++ src/SimpleTypeSystem.h	2013-09-05 22:40:17 +0000
@@ -1,4 +1,23 @@
 
+/*
+    (C) Gustav Hartvigsson, 2013.
+    
+    This program is free software: you can redistribute it and/or modify
+    it under the terms of the GNU Lesser General Public License as
+    published by the Free Software Foundation, either version 3 of the
+    License.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
+
+/** @file */
+
 #ifndef __H_SIMPLE_TYPE_SYSTEM__
 #define __H_SIMPLE_TYPE_SYSTEM__
 
@@ -11,9 +30,24 @@
 #include "Error.h"
 #include "Func.h"
 
+/**
+ * Returns a string representing the current version.
+ */
 char * s_get_version_string ();
+
+/**
+ * Returns the Major version as on int.
+ */
 int s_get_version_major ();
+
+/**
+ * Returns the Minor version as on int.
+ */
 int s_get_version_minor ();
+
+/**
+ * Returns the Patch version as on int.
+ */
 int s_get_version_patch ();
 
 char * s_string_new (const char * s);

=== modified file 'src/baseobject.h'
--- src/baseobject.h	2013-09-04 15:05:39 +0000
+++ src/baseobject.h	2013-09-05 22:40:17 +0000
@@ -15,6 +15,8 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+/** @file */
+
 #ifndef __H_BASE_OBJECT__
 #define __H_BASE_OBJECT__
 
@@ -24,22 +26,17 @@
  * ---------------------------------------------------
  */
 
-/**
- * The class holds all the "virtual" functions/methods that are to be used with
- * the object.
- * 
- * 
- */
+
 typedef struct _SBaseObjectClass SBaseObjectClass;
 
-/**
- * The instance holds the data that is associated with the object.
- * it also holds a pointer to the class of the object.
- * 
- * 
- */
+
 typedef struct _SBaseObjectInstance SBaseObjectInstance;
 
+/**
+ * The class holds all the "virtual" functions, also knows  as methods
+ * that are to be used with the object.
+ * 
+ */
 struct _SBaseObjectClass {
   // SBaseObjectInstance * (* initize)(SBaseObjectInstance *);
   void (*deinitize)(SBaseObjectInstance *);
@@ -49,6 +46,11 @@
   char * (*to_string)(SBaseObjectInstance *);
 };
 
+/**
+ * The instance holds the data that is associated with the object.
+ * it also holds a pointer to the class of the object.
+ * 
+ */
 struct _SBaseObjectInstance {
   SBaseObjectClass * base_class;
   unsigned int refcount;
@@ -59,8 +61,8 @@
  * Helper functions...
  * -----------------
  */
-/**
- * This function is used to set the method to initize a new instance of an
+/*
+ * This function is used to set the method to initialize a new instance of an
  * object.
  *
  * This has no use, rely...(?)
@@ -68,41 +70,41 @@
 // void s_base_object_set_init_method (SBaseObjectInstance * self, SBaseObjectInstance * (* method)(* SBaseObjectInstance));
 
 /**
- * This function is used to set the method to deinitize an object.
+ * This function is used to set the method to deinitialize an object.
  * 
- * set it to a method that deinitize your object.
+ * set it to a method that deinitialize your object.
  */
 void s_base_object_set_deinit_method (SBaseObjectInstance * self, void (* method)(SBaseObjectInstance *));
 
 /**
- * This fuction is used to set the ref method.
+ * This function is used to set the ref method.
  * 
  * DO NOT USE THIS UNLESS YOU KNOW WHAT YOU ARE DOING.
  */
 void s_base_object_set_ref_method (SBaseObjectInstance * self, int (* method)(SBaseObjectInstance *));
 
 /**
- * This fuction is used to set the unref method.
+ * This function is used to set the unref method.
  * 
  * DO NOT USE THIS UNLESS YOU KNOW WHAT YOU ARE DOING.
  */
 void s_base_object_set_unref_method (SBaseObjectInstance * self, int (* method)(SBaseObjectInstance *));
 
-/**
- * This fuction is used to set the get_refcount method.
+/**!
+ * This function is used to set the get_refcount method.
  * 
  * DO NOT USE THIS UNLESS YOU KNOW WHAT YOU ARE DOING.
  */
 void s_base_object_set_get_refcount_method (SBaseObjectInstance * self, int (* method)(SBaseObjectInstance *));
 
-/**
- * This fuction is used to set the to_string method.
+/**!
+ * This function is used to set the to_string method.
  */
 void s_base_object_set_to_string_method (SBaseObjectInstance * self, char * (* method)(SBaseObjectInstance *));
 
 
 /*
- * concreate functions are defined in the C file.
+ * concrete functions are defined in the C file.
  */
 
 /* ----------------------
@@ -110,20 +112,28 @@
  * ----------------------
  */
 
-/**
- * This function initizes an intance of the BaseObject, it also sets the methods
- * to be used with the object and sets the refrence count to one.
+/** @brief
+ * Initializes an SBaseObjectInstance
+ * 
+ * @param self The object to initialize.
+ * 
+ * This function initializes an instance of the SBaseObjectInstance, it also sets
+ * the methods to be used with the object and sets the reference count to one.
  */
 void s_base_object_initize (SBaseObjectInstance * self);
 
-/**
+/** @brief
  * This function creates a new base object.
+ * 
+ * 
+ * 
+ * @return a new SBaseObjectInstance
  */
 SBaseObjectInstance * s_base_object_new ();
 
 /**
- * This function deinitizes/frees an object even if it is still referenced.
- * This is usualy a bad idea, use s_base_object_unref instead.
+ * This function desensitizes/frees an object even if it is still referenced.
+ * This is usually a bad idea, use s_base_object_unref () instead.
  */
 void s_base_object_free (SBaseObjectInstance * self);
 
@@ -139,27 +149,27 @@
 
 /**
  * This function is used to decrese the reference count of an object.
- * When an object reaches zero, it will deinitize the object using the objects
- * deititize method.
+ * When an object reaches zero, it will deinitialize the object using the
+ * objects deinitialize method.
  * 
  * It returns the current (after change) reference count.
  */
 int s_base_object_unref (SBaseObjectInstance * self);
 
 /**
- * This function is used to increse the reference count of an object.
+ * This function is used to increase the reference count of an object.
  *
  * Returns the current (after change) reference count.
  */
 int s_base_object_ref (SBaseObjectInstance * self);
 
 /**
- * This function returns the current reference count without chaning it.
+ * This function returns the current reference count without changing it.
  */
 int s_base_object_get_refcount (SBaseObjectInstance * self);
 
 /**
- * This function returns a textual (string) that represesnts the object.
+ * This function returns a textual (string) that represents the object.
  * The method can be set using s_base_object_set_to_string_method.
  *
  * Note: The string that is returned must be freed.

